/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
 
//
// This source code implements constants defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//

package javax.jbi.messaging;

/**
 * <p>
 * Defines constants linked to the normalized message properties:
 * <ul>
 * <li><b>javax.jbi.security.subject</b>. JAAS security subject responsible who
 * signed the message, or that will be needed to sign the message.</li>
 * <li><b>javax.jbi.messaging.protocol.type</b>. The protocol type name (using
 * the same values as the WSDL 2.0 binding type attribute) of the binding that
 * created the message.</li>
 * <li><b>javax.jbi.messaging.protocol.headers</b>. A set of name/value pairs
 * specific to the protocol used by the binding. The names must be Strings; the
 * values are of a binding-defined type. (For SOAP headers, these values are
 * org.w3c.dom.DocumentFragment nodes).</li>
 * </ul>
 * </p>
 * <p>
 * <b>Note</b> that the javax.jbi.messaging.protocol.type and
 * javax.jbi.messaging.protocol.headers properties are set by binding
 * components. These values are typically used only by the binding component
 * itself, since they are binding-specific. Other components may use these
 * properties, however, this is a poor practice, since it can bind the component
 * to a particular protocol.
 * </p>
 *
 * @author JSR208 Expert Group
 */
public final class NormalizedMessageProperties {

    /**
     * javax.jbi.security.subject
     */
    public static final String SECURITY_SUBJECT = "javax.jbi.security.subject";

    /**
     * javax.jbi.messaging.protocol.type
     */
    public static final String PROTOCOL_TYPE = "javax.jbi.messaging.protocol.type";

    /**
     * javax.jbi.messaging.protocol.headers
     */
    public static final String PROTOCOL_HEADERS = "javax.jbi.messaging.protocol.headers";

    /**
     * No constructor because it's a class containing only constants.
     */
    private NormalizedMessageProperties() {
        // NOP
    }
}
